PACE package sparsisity analysis
================

-   [Chronic lymphocytic leukemia](#chronic-lymphocytic-leukemia)
    -   [What is a chronic leukemia](#what-is-a-chronic-leukemia)
    -   [What is a lymphocytic leukemia?](#what-is-a-lymphocytic-leukemia)
    -   [Are there different types of CLL?](#are-there-different-types-of-cll)
-   [Using L1, L2, Elastic net and each combination with DegreeCox](#using-l1-l2-elastic-net-and-each-combination-with-degreecox)
    -   [General Options](#general-options)
    -   [Install required packages](#install-required-packages)
    -   [Load library pace](#load-library-pace)
        -   [Setup parallel computing if necessary](#setup-parallel-computing-if-necessary)
    -   [Data](#data)
        -   [Expression levels](#expression-levels)
        -   [Select data with expression levels](#select-data-with-expression-levels)
    -   [Normalize matrix](#normalize-matrix)
-   [Regularization Setup](#regularization-setup)
    -   [Options](#options)
    -   [General function called in regularization](#general-function-called-in-regularization)
    -   [Setup xdata, ydata and functions](#setup-xdata-ydata-and-functions)
-   [Regularization](#regularization)
    -   [LASSO (l1 normalization)](#lasso-l1-normalization)
        -   [Lasso only](#lasso-only)
        -   [Degree-penalized Lasso](#degree-penalized-lasso)
    -   [Ridge (l2 normalization)](#ridge-l2-normalization)
        -   [Calculate Ridge only](#calculate-ridge-only)
        -   [Degree-penalized Ridge (**DegreeCox**)](#degree-penalized-ridge-degreecox)
    -   [Elastic net (l1 and l2 normalization)](#elastic-net-l1-and-l2-normalization)
        -   [Calculate Elastic Net only](#calculate-elastic-net-only)
        -   [Degree-penalized Elastic Net](#degree-penalized-elastic-net)
-   [Interesting genes](#interesting-genes)
    -   [L1 + L2 + Degree](#l1-l2-degree)

Chronic lymphocytic leukemia
============================

(information from [cancer.org](http://www.cancer.org/cancer/leukemia-chroniclymphocyticcll/detailedguide/leukemia-chronic-lymphocytic-what-is-cll))

Chronic lymphocytic leukemia (CLL) is a type of cancer that starts from cells that become certain white blood cells (called lymphocytes) in the bone marrow. The cancer (leukemia) cells start in the bone marrow but then go into the blood.

In CLL, the leukemia cells often build up slowly over time, and many people don't have any symptoms for at least a few years. In time, the cells can spread to other parts of the body, including the lymph nodes, liver, and spleen.

What is a chronic leukemia
--------------------------

Whether leukemia is acute or chronic depends on whether most of the abnormal cells are immature (and are more like stem cells) or mature (and are like normal white blood cells).

In chronic leukemia, the cells can mature partly but not completely. These cells may look fairly normal, but they are not. They generally do not fight infection as well as normal white blood cells do. The leukemia cells survive longer than normal cells, and build up, crowding out normal cells in the bone marrow. Chronic leukemias can take a long time before they cause problems, and most people can live for many years. But chronic leukemias are generally harder to cure than acute leukemias.

What is a lymphocytic leukemia?
-------------------------------

Whether leukemia is myeloid or lymphocytic depends on which bone marrow cells the cancer starts in.

Lymphocytic leukemias (also known as lymphoid or lymphoblastic leukemia) start in the cells that become lymphocytes. Lymphomas are also cancers that start in those cells. The main difference between lymphocytic leukemias and lymphomas is that in leukemia, the cancer cell is mainly in the bone marrow and blood, while in lymphoma it tends to be in lymph nodes and other tissues.

Are there different types of CLL?
---------------------------------

Doctors have found that there seem to be 2 different kinds of CLL:

1.  One kind of CLL grows very slowly and so it may take a long time before the patient needs treatment.
2.  The other kind of CLL grows faster and is a more serious disease.

The leukemia cells from these 2 types look alike, but lab tests can tell the difference between them. The tests look for proteins called ZAP-70 and CD38. If the CLL cells contain low amounts of these proteins, the leukemia tends to grow more slowly.

Using L1, L2, Elastic net and each combination with DegreeCox
=============================================================

General Options
---------------

``` r
nfolds       <- 5     # number of folds in cross-validation
nlambda      <- 1000  # number of lambdas that should be calculated
is.parallel  <- TRUE  # use parallel computing (if available) in cross-validation?
#
# if all samples should be used, then training set = test set, otherwise
#  the two sets are complements.
training.set  <- .9
training.seed <- 65087 # reproducible results
#
training.set  <- .5
# selected from having at least 9 events in test set. (first - 45434 - has 11)
training.seed.list <- c(45434, 18628, 62002, 16801, 73033, 51529, 16239, 137920, 74779, 57774, 56389, 8164)
training.seed <- training.seed.list[1] # reproducible results
```

Install required packages
-------------------------

``` r
  # CRAN Packages
  required.pack <- c('KernSmooth','gplots', 'ggtern', 'maxstat', 'ggdendro', 
                     'forestplot', 'LSD', 'beeswarm', 'VennDiagram', 'doMC', 
                     'foreach', 'corrplot', 'survival', 'R.utils', 'Hmisc',
                     'glmnet', 'devtools', 'ggfortify')
  for (pack in required.pack) {
    if (!(pack %in% rownames(installed.packages()))) {
      install.packages(pack)
    }
  }
  # github
  devtools::install_github('averissimo/verissimo-rpackage')
```

    ## Skipping install of 'verissimo' from a github remote, the SHA1 (ccbe9fad) has not changed since last install.
    ##   Use `force = TRUE` to force installation

``` r
  # BioConductor packages
  source("https://bioconductor.org/biocLite.R")
```

    ## Bioconductor version 3.3 (BiocInstaller 1.22.3), ?biocLite for help

``` r
  required.pack.bioC <- c('vsn','genefilter')
  for (pack in required.pack.bioC) {
    if (!(pack %in% rownames(installed.packages()))) {
      biocLite(pack)
    }
  }
  # Pace packages from source
  if (!('pace' %in% rownames(installed.packages())))
    install.packages('./package', repos = NULL,type = 'source')
```

Load library pace
-----------------

This library was obtained from Wolfgang Huber in CSAMA 2016

``` r
suppressPackageStartupMessages({
  library(pace)
  library(Hmisc)
  library(futile.logger)
  library(digest)
  library(survival)
  library(glmnet)
  library(verissimo)
})
do.nothing <- flog.appender(appender.tee('logger.txt'))
```

### Setup parallel computing if necessary

``` r
suppressPackageStartupMessages({
  library(doMC) # parallel computing
  library(foreach)
})
# Parallel
registerDoMC(cores=10) 
```

Data
----

loading data from package and filter only by CLL

``` r
data(list=c("recipe", "conctab", "patmeta", "drugs", "mutCOM", "surv"))

lpdCLL <- lpdAll[ , lpdAll$Diagnosis=="CLL"   ]

rnaColumns <- lpdCLL@featureData@data$type == 'RNA'

expr <- lpdCLL@assayData$exprs[rnaColumns,]

flog.info('Columns for survival object:', colnames(survT), capture = TRUE)
```

    ## INFO [2016-09-13 17:28:29] Columns for survival object:
    ## 
    ##  [1] "T5"                  "T6"                  "treated"            
    ##  [4] "treatedAfter"        "died"                "IC50beforeTreatment"
    ##  [7] "IGHV"                "trisomy12"           "TP53"               
    ## [10] "del17p13"            "sampleStatus"

### Expression levels

Count the number of expression levels by sample to figure out which has missing values.

``` r
count.missing <- sapply(1:ncol(expr), function(e){sum(is.na(expr[,e]))})
flog.info('Number of samples with expression levels by sample: %d/%d', sum(count.missing == 0), ncol(lpdCLL))
```

    ## INFO [2016-09-13 17:28:29] Number of samples with expression levels by sample: 92/184

### Select data with expression levels

Get data that has all RNA-seq and calculate Pearson correlation on the genes. - When getting the correlation matrix, use the absolute values as edge weights

``` r
lpdCLL.rna <- lpdCLL[ , count.missing == 0]

if (training.set == 1) {
  lpdTest  <- lpdCLL.rna
  lpdTrain <- lpdCLL.rna
} else {
  sample.size <- floor(training.set * ncol(lpdCLL.rna))
  ## this commented code allows to find seeds that have a minimum of events
  ##  in test set
  #for(ix in 1:10000) {
  #  training.seed <- abs(floor(rnorm(1) * 100000))
  set.seed(training.seed)
  train.ix <- sample(seq_len(ncol(lpdCLL.rna)), size = sample.size)
  lpdTrain <- lpdCLL.rna[ ,  train.ix]
  lpdTest  <- lpdCLL.rna[ , -train.ix]
  #  if (sum(lpdTest@phenoData@data$died) == 9) {
  #    flog.info('Found it: %d', training.seed)
  #    # break
  #  }
  #}
      
  flog.info('Test data has %d samples that have died and %d that are censored.', 
            sum(lpdTest@phenoData@data$died),
            sum(!lpdTest@phenoData@data$died))
  # create variable with expression data
  # TODO: filter the assay data in lpdTrain to only RNA data
  expr <- lpdTrain@assayData$exprs[rnaColumns,]
}
```

    ## INFO [2016-09-13 17:28:29] Test data has 11 samples that have died and 35 that are censored.

``` r
# Must transpose the matrix, such as each column is a feature that will calculate the correlation
cor.pearson <- cor(t(expr), method = 'pearson')

# remove diagonal
diag(cor.pearson) <- 0

# set absolute values
cor.pearson.abs <- abs(cor.pearson)
```

Normalize matrix
----------------

``` r
# use the md5 digest to create a signature of the .abs to store .norm
cache.file <- file.path('cache', 
                        paste0('cor.pearson.abs.', 
                               digest(cor.pearson.abs, algo = 'md5'), 
                               '.RData'))

# if a cached file already exists with the same signature, then it should be used
#  instead of recalculating
if (file.exists(cache.file)) {
  flog.info('%s\n%s', 'Loading cache file instead of calculating all...',
            '  (note that cache file is referenced by md5sum of cor.pearson.abs matrix)')
  load(cache.file)
} else {
  flog.info('Performing the normalization of cor.pearson.abs... (this could take a while)')
  sum.cols <- sqrt(colSums(cor.pearson.abs))
  sum.rows <- sqrt(rowSums(cor.pearson.abs))
  
  # divide the problem in 4 different partitions
  my.probs <- seq(0,1, 1 / (getDoParWorkers()))
  my.probs <- my.probs[2:length(my.probs)]
  quants <- c(0,round(quantile(1:nrow(cor.pearson.abs), probs = my.probs)))
  # for each partition calculate the normalization
  cor.pearson.norm <- foreach( ix = 2:length(quants), .combine = rbind ) %dopar% {
    # foreach was not very eficient done row by row, so this partion scheme
    #  must be done, probably a better parallization framework could have been
    #  used
    t(sapply((quants[ix-1] + 1):quants[ix], function(row.ix) {
      # actuall calculations done here
      sapply(1:ncol(cor.pearson.abs), function(col.ix) {
        cor.pearson.abs[row.ix,col.ix] / sum.cols[col.ix] / sum.rows[row.ix]
      })
    }))
    # seems like calculations are done pretty quick, rsession takes a while to
    #  join the results
  }
  save(file = cache.file, 'cor.pearson.norm')
}
```

    ## INFO [2016-09-13 17:28:46] Loading cache file instead of calculating all...
    ##   (note that cache file is referenced by md5sum of cor.pearson.abs matrix)

``` r
flog.info('cor.pearson.norm has size of %d rows and %d columns (which should be the same)',
          nrow(cor.pearson.norm), ncol(cor.pearson.norm))
```

    ## INFO [2016-09-13 17:28:49] cor.pearson.norm has size of 15366 rows and 15366 columns (which should be the same)

Calculate the degree of each node and normalize by column and row

``` r
# Simple sum of node edges
degree.abs <- 1 / colSums(cor.pearson.abs)
degree.abs <- degree.abs / max(degree.abs)
# Simple sum of node edges
degree.norm <- 1 / colSums(cor.pearson.norm)
degree.norm <- degree.norm / max(degree.norm)
# show summaries
flog.info('Summary on degree (absolute):',summary(degree.abs),capture = TRUE)
```

    ## INFO [2016-09-13 17:28:49] Summary on degree (absolute):
    ## 
    ##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
    ##  0.2656  0.3678  0.4337  0.4492  0.5136  1.0000

``` r
flog.info('Summary on degree (normalized):', summary(degree.norm), capture = TRUE)
```

    ## INFO [2016-09-13 17:28:49] Summary on degree (normalized):
    ## 
    ##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
    ##  0.5588  0.6410  0.6874  0.6942  0.7387  1.0000

``` r
# select which metric to use
degree <- degree.abs
```

Regularization Setup
====================

Options
-------

Alpha parameter can be \[0,1\], where 0 is the same as Ridge and 1 Lasso. Anything in the middle is a weighted regularization between L1 and L2 norm.

General function called in regularization
-----------------------------------------

``` r
my.cv.glmnet <- function(xdata, ydata, penalty.factor) {
  return(cv.glmnet(xdata, Surv(ydata[,1], ydata[,2]), 
                   nfolds = nfolds, parallel = is.parallel, 
                   family='cox', 
                   alpha = alpha, nlambda = nlambda, 
                   standardize = T, 
                   penalty.factor = penalty.factor))
}

print.results <- function(xdata, ydata, results) {
  lambda.min.ix <- which(results$lambda == results$lambda.min)
  lambda.1se.ix <- which(results$lambda == results$lambda.1se)
  flog.info("best lambda: %f | non-zero: %d", results$lambda.min,
            sum(results$glmnet.fit$beta[,lambda.min.ix] != 0))
  flog.info(" 1se lambda: %f | non-zero: %d", results$lambda.1se,
            sum(results$glmnet.fit$beta[,lambda.1se.ix] != 0))
  
  # commented out as cox.model was not really required, just the coefficients
  # cox.model <- coxph.fit(xdata, ydata, strata = NULL, init = results$glmnet.fit$beta[,lambda.min.ix], 
  #                       control = coxph.control(outer.max = 0, iter.max = 0), method = 'breslow',
  #                       rownames = NULL)
  #
  # compatibility with coxph.fit model
  cox.model <- list(coefficients = results$glmnet.fit$beta[,lambda.min.ix])
  return(cox.model)
}

my.draw.kaplan <- function(coeff, xdata, ydata, name) {
  my.list <- list()
  my.list[[name]] <- coeff
  draw.kaplan(my.list, xdata.test, ydata.test, 
              legend.outside = F, filename = name, expand.yzero = T)
}
```

Setup xdata, ydata and functions
--------------------------------

``` r
# xdata already setup above, but needs to be transposed
#     rows: observations
#  columns: features
xdata.test <- t(lpdTest@assayData$exprs[rnaColumns,])
ydata.test <- data.frame(time = lpdTest@phenoData@data$T6, 
                         status = lpdTest@phenoData@data$died, 
                         row.names = rownames(lpdTest@phenoData@data))
#
# xdata.test <- t(lpdCLL.rna@assayData$exprs[rnaColumns,])
# ydata.test <- data.frame(time = lpdCLL.rna@phenoData@data$T6,
#                          status = lpdCLL.rna@phenoData@data$died,
#                          row.names = rownames(lpdCLL.rna@phenoData@data))
#
xdata.train <- t(lpdTrain@assayData$exprs[rnaColumns,])
ydata.train <- data.frame(time = lpdTrain@phenoData@data$T6, 
                          status = lpdTrain@phenoData@data$died, 
                          row.names = rownames(lpdTrain@phenoData@data))
#
# adjust to months
ydata.test$time  <- ydata.test$time * 12
ydata.train$time <- ydata.train$time * 12
```

Regularization
==============

LASSO (l1 normalization)
------------------------

Using a sparse LASSO regularization with Cox proportional hazards model. When using the glmnet package, alpha should be 1.

``` r
alpha <- 1
```

### Lasso only

Run the model.

``` r
my.penalty   <- array(1,ncol(xdata.train))
results.l1   <- my.cv.glmnet(xdata.train, ydata.train, my.penalty)
# flog.info('Building cox model... (it can take a while)')
cox.model.l1 <- print.results(xdata.train, ydata.train, results.l1)
```

    ## INFO [2016-09-13 17:29:00] best lambda: 0.174093 | non-zero: 8
    ## INFO [2016-09-13 17:29:00]  1se lambda: 0.250576 | non-zero: 0

``` r
res          <- my.draw.kaplan(cox.model.l1$coefficients, 
                               xdata.test, ydata.test, "L1")
res$plot # show plot
```

![](analysis_files/figure-markdown_github/calculate_l1-1.png)

``` r
res$km   # show kaplan-meier summary
```

    ## Call: survfit(formula = Surv(time, status) ~ group, data = prognostic.index.df)
    ## 
    ##                 n events median 0.95LCL 0.95UCL
    ## Low risk - L1  23      4     NA      NA      NA
    ## High risk - L1 23      7     NA    22.4      NA

### Degree-penalized Lasso

Penalizing the degree using the glmnet framework that includes a penalty.factor to control the shrinkage.

``` r
my.penalty         <- degree
results.l1.degree  <- my.cv.glmnet(xdata.train, ydata.train, my.penalty)
# flog.info('Building cox model... (it can take a while)')
cox.model.l1.degre <- print.results(xdata.train, ydata.train, results.l1.degree)
```

    ## INFO [2016-09-13 17:29:12] best lambda: 0.253199 | non-zero: 1
    ## INFO [2016-09-13 17:29:12]  1se lambda: 0.268836 | non-zero: 0

``` r
res                <- my.draw.kaplan(cox.model.l1.degre$coefficients, 
                                     xdata.test, ydata.test, "L1 + Degree")
res$plot # show plot
```

![](analysis_files/figure-markdown_github/calculate_l1.degree-1.png)

``` r
res$km   # show kaplan-meier summary
```

    ## Call: survfit(formula = Surv(time, status) ~ group, data = prognostic.index.df)
    ## 
    ##                          n events median 0.95LCL 0.95UCL
    ## Low risk - L1 + Degree  23      6     NA      NA      NA
    ## High risk - L1 + Degree 23      5     NA      NA      NA

Ridge (l2 normalization)
------------------------

``` r
alpha <- 0
```

### Calculate Ridge only

``` r
my.penalty   <- array(1,ncol(xdata.train))
results.l2   <- my.cv.glmnet(xdata.train, ydata.train, my.penalty)
# flog.info('Building cox model... (it can take a while)')
cox.model.l2 <- print.results(xdata.train, ydata.train, results.l2)
```

    ## INFO [2016-09-13 17:29:47] best lambda: 146.793511 | non-zero: 15366
    ## INFO [2016-09-13 17:29:47]  1se lambda: 250.575779 | non-zero: 15366

``` r
res          <- my.draw.kaplan(cox.model.l2$coefficients, 
                               xdata.test, ydata.test, "L2")
res$plot # show plot
```

![](analysis_files/figure-markdown_github/calculate_l2-1.png)

``` r
res$km   # show kaplan-meier summary
```

    ## Call: survfit(formula = Surv(time, status) ~ group, data = prognostic.index.df)
    ## 
    ##                 n events median 0.95LCL 0.95UCL
    ## Low risk - L2  23      2     NA      NA      NA
    ## High risk - L2 23      9   30.7    22.4      NA

### Degree-penalized Ridge (**DegreeCox**)

``` r
my.penalty          <- degree
results.l2.degree   <- my.cv.glmnet(xdata.train, ydata.train, my.penalty)
# flog.info('Building cox model... (it can take a while)')
cox.model.l2.degree <- print.results(xdata.train, ydata.train, results.l2.degree)
```

    ## INFO [2016-09-13 17:30:32] best lambda: 94.849579 | non-zero: 15366
    ## INFO [2016-09-13 17:30:32]  1se lambda: 268.836270 | non-zero: 15366

``` r
res                 <- my.draw.kaplan(cox.model.l2.degree$coefficients, 
                                      xdata.test, ydata.test, "L2 + Degree")
res$plot # show plot
```

![](analysis_files/figure-markdown_github/calculate_l2_degree-1.png)

``` r
res$km   # show kaplan-meier summary
```

    ## Call: survfit(formula = Surv(time, status) ~ group, data = prognostic.index.df)
    ## 
    ##                          n events median 0.95LCL 0.95UCL
    ## Low risk - L2 + Degree  23      3     NA      NA      NA
    ## High risk - L2 + Degree 23      8     NA    22.4      NA

Elastic net (l1 and l2 normalization)
-------------------------------------

``` r
alpha <- 0.5
```

### Calculate Elastic Net only

``` r
my.penalty      <- array(1,ncol(xdata.train))
results.l1.l2   <- my.cv.glmnet(xdata.train, ydata.train, my.penalty)
# flog.info('Building cox model... (it can take a while)')
cox.model.l1.l2 <- print.results(xdata.train, ydata.train, results.l1.l2)
```

    ## INFO [2016-09-13 17:30:44] best lambda: 0.265273 | non-zero: 35
    ## INFO [2016-09-13 17:30:44]  1se lambda: 0.501152 | non-zero: 0

``` r
res             <- my.draw.kaplan(cox.model.l1.l2$coefficients, 
                               xdata.test, ydata.test, "L1 + L2")
res$plot # show plot
```

![](analysis_files/figure-markdown_github/calculate_l1.l2-1.png)

``` r
res$km   # show kaplan-meier summary
```

    ## Call: survfit(formula = Surv(time, status) ~ group, data = prognostic.index.df)
    ## 
    ##                      n events median 0.95LCL 0.95UCL
    ## Low risk - L1 + L2  23      3     NA      NA      NA
    ## High risk - L1 + L2 23      8     NA    22.4      NA

### Degree-penalized Elastic Net

``` r
my.penalty             <- degree
results.l1.l2.degree   <- my.cv.glmnet(xdata.train, ydata.train, my.penalty)
# flog.info('Building cox model... (it can take a while)')
cox.model.l1.l2.degree <- print.results(xdata.train, ydata.train, results.l1.l2.degree)
```

    ## INFO [2016-09-13 17:30:57] best lambda: 0.361698 | non-zero: 18
    ## INFO [2016-09-13 17:30:57]  1se lambda: 0.537673 | non-zero: 0

``` r
res                    <- my.draw.kaplan(cox.model.l1.l2.degree$coefficients, 
                                      xdata.test, ydata.test, "L1 + L2 + Degree")
res$plot # show plot
```

![](analysis_files/figure-markdown_github/calculate_l1.l2_degree-1.png)

``` r
res$km   # show kaplan-meier summary
```

    ## Call: survfit(formula = Surv(time, status) ~ group, data = prognostic.index.df)
    ## 
    ##                               n events median 0.95LCL 0.95UCL
    ## Low risk - L1 + L2 + Degree  23      1     NA      NA      NA
    ## High risk - L1 + L2 + Degree 23     10   30.7      19      NA

Interesting genes
=================

L1 + L2 + Degree
----------------

``` r
ix <- cox.model.l1.l2.degree$coefficients != 0
ix.names <- names(ix)[ix]
my.genes <- lpdTest@featureData@data[ix.names,]
if (!all(rownames(my.genes) == ix.names)) {
  for(i in 1:5) {flog.error('Problem ix!!') }
}
cbind(my.genes, l1.l2.degree = cox.model.l1.l2.degree$coefficients[ix])
```

    ##                         name type   id subtype l1.l2.degree
    ## ENSG00000069248       NUP133  RNA <NA>    <NA> -0.193748423
    ## ENSG00000100605        ITPK1  RNA <NA>    <NA> -0.067101640
    ## ENSG00000127561       SYNGR3  RNA <NA>    <NA> -0.041076676
    ## ENSG00000132704        FCRL2  RNA <NA>    <NA> -0.005133590
    ## ENSG00000133597        ADCK2  RNA <NA>    <NA> -0.007120218
    ## ENSG00000137145      DENND4C  RNA <NA>    <NA> -0.026700200
    ## ENSG00000137154         RPS6  RNA <NA>    <NA> -0.057655675
    ## ENSG00000138398         PPIG  RNA <NA>    <NA> -0.019890368
    ## ENSG00000143761         ARF1  RNA <NA>    <NA> -0.171020754
    ## ENSG00000143793      C1orf35  RNA <NA>    <NA> -0.002898626
    ## ENSG00000145390        USP53  RNA <NA>    <NA> -0.049686036
    ## ENSG00000152242     C18orf25  RNA <NA>    <NA>  0.130417650
    ## ENSG00000163785          RYK  RNA <NA>    <NA> -0.087023002
    ## ENSG00000165923        AGBL2  RNA <NA>    <NA>  0.144919254
    ## ENSG00000168394         TAP1  RNA <NA>    <NA>  0.006115781
    ## ENSG00000168899        VAMP5  RNA <NA>    <NA>  0.006603630
    ## ENSG00000179240 LOC100506127  RNA <NA>    <NA>  0.123102024
    ## ENSG00000267002               RNA <NA>    <NA>  0.206335784
