TUM -- Rare Mitochondrial disorders
================

-   [Retrieve data from TUM](#retrieve-data-from-tum)
-   [Description of the data](#description-of-the-data)
-   [Normalize the data](#normalize-the-data)
-   [Perform elastic net](#perform-elastic-net)
    -   [Plot cross validation curves](#plot-cross-validation-curves)
-   [Results](#results)

*From [Article in biorxiv](http://biorxiv.org/content/biorxiv/early/2016/07/29/066738.full.pdf)*

Mitochondrial disorders represents the most frequent inborn errors of metabolism affecting 1 in 4,300 birth1. The genetic basis is large with causative defects identified in approximately 300 genes and a presumably large number of additional disease-associated genes still awaiting identification2.

For the majority of patients, disease mechanisms can be assayed in dermal fibroblasts even though the disease may manifest in different tissues. This allows rapid demonstration of the necessary and sufficient role of candidate variants by complementation assays. It also indicates that disease-causing expression defects, if any, should be detectable in these cells.

Retrieve data from TUM
----------------------

Data is downloaded from TUM and kept in cache folder. See [TUM link](https://i12g-gagneurweb.in.tum.de/public/paper/mitoMultiOmics/paper_supplement_data/) for complete listing of data available.

Description of the data
=======================

Sample size

``` r
flog.info('Number of samples: %d', ncol(gene.counts))
```

    ## INFO [2016-10-13 17:14:37] Number of samples: 119

Genes

``` r
flog.info('Number of genes: %d', nrow(gene.counts))
```

    ## INFO [2016-10-13 17:14:37] Number of genes: 12680

Summary of Diseases

``` r
flog.info('Summary of diseases', t(t(summary(sample.annotation$DISEASE))), capture = TRUE)
```

    ## INFO [2016-10-13 17:14:37] Summary of diseases
    ## 
    ##                                   [,1]
    ## BPAN                                 1
    ## COASY                                1
    ## DNAJC3                               2
    ## DPYD                                13
    ## HEALTHY                              9
    ## MITO                                75
    ## PAED                                 1
    ## PKAN                                 2
    ## PLAN                                 1
    ## RALF                                 3
    ## SQSTM1                               2
    ## V.a.lysosomale Speichererkrankung    1
    ## NA's                                 8

Normalize the data
==================

``` r
# no normalization
norm.no.gene.counts <- gene.counts
# center the variable
norm.center.gene.counts <- t(apply(gene.counts, 1, function(x){(x - mean(x))/sd(x)}))
# using the maximum
norm.max.gene.counts    <- t(apply(gene.counts, 1, function(x){x/max(abs(x))}))
```

Perform elastic net
===================

``` r
# alpha parameter
alpha   <- .5  # 1 lasso, 0 ridge, 0.5 elastic net
nfolds  <- 84  # 84 is leave one out
nlambda <- 100 #
# filter only samples with diseases:HEALTHY and MITO
ydata.sample <- sample.annotation[sample.annotation$DISEASE == 'MITO' | sample.annotation$DISEASE == 'HEALTHY',]
ydata.sample <- ydata.sample[!is.na(ydata.sample$DISEASE),]
ydata <- as.numeric(ydata.sample$DISEASE)

my.results      <- list()
my.results$cv   <- list()
my.results$best <- list()
#
my.results$xdata <- list(NoNorm = norm.no.gene.counts,
                         Center = norm.center.gene.counts,
                         Max = norm.max.gene.counts)
#
for (norm.ix in names(my.results$xdata)) {
  #
  my.results$xdata[[norm.ix]] <- as.matrix(t(my.results$xdata[[norm.ix]][,ydata.sample$RNA_ID]))
  xdata <- my.results$xdata[[norm.ix]]
  #
  my.results$cv[[norm.ix]] <- cv.glmnet(xdata,                    ydata , 
                             alpha       = alpha,      nlambda      = nlambda,
                             family      = 'binomial', type.measure = 'class', 
                             standardize = F,          parallel     = TRUE,     nfolds = nfolds)
  #
  my.results$best[[norm.ix]] <- glmnet(xdata, ydata, alpha = alpha, family = 'binomial', lambda = my.results$cv$lambda, standardize = F)
  # set class names
  my.results$best[[norm.ix]]$classnames <- levels(ydata.sample$DISEASE)[as.numeric(my.results$best[[norm.ix]]$classnames)]
}
```

    ## Warning: Option grouped=FALSE enforced in cv.glmnet, since < 3 observations
    ## per fold

    ## Warning: Option grouped=FALSE enforced in cv.glmnet, since < 3 observations
    ## per fold

    ## Warning: Option grouped=FALSE enforced in cv.glmnet, since < 3 observations
    ## per fold

Plot cross validation curves
----------------------------

``` r
my.results$cv.plots <- list()
for (norm.ix in names(my.results$xdata)) {
  my.results$cv.plots[[norm.ix]] <- autoplot(my.results$cv[[norm.ix]], ylab = 'Misclass.', main = norm.ix) + theme_bw()
}
grid.arrange(my.results$cv.plots$NoNorm, my.results$cv.plots$Center, my.results$cv.plots$Max)
```

![](tum_files/figure-markdown_github/plot_cv-1.png)

Results
=======

``` r
for (norm.ix in names(my.results$xdata)) {
  best.lambda.ix <- which(my.results$best[[norm.ix]]$lambda == my.results$cv[[norm.ix]]$lambda.min)
  my.predic <- predict(my.results$best[[norm.ix]], newx = as.matrix(my.results$xdata[[norm.ix]]), type = 'class')
  
  accuracy <- data.frame(ix = length(my.results$best[[norm.ix]]$df):1,
                         predictors = my.results$best[[norm.ix]]$df,
                         accuracy = 1 - apply(my.predic, 2, function(x){ sum(ydata.sample$DISEASE == x) }) / nrow(ydata.sample),
                         group = rep(norm.ix, length(my.results$best[[norm.ix]]$df)))
  ticksLabel <- my.results$best[[norm.ix]]$df
  maxY <- round(max(accuracy$accuracy)* 1.2 ,2)
  my.results$plots[[norm.ix]] <- ggplot(accuracy, aes(x = ix, y = accuracy)) + geom_point() +
                   scale_x_continuous(breaks = seq(length(ticksLabel),1, -round(length(ticksLabel)/20)), labels = ticksLabel[seq(1, length(ticksLabel), round(length(ticksLabel)/20))]) + 
                   scale_y_continuous(limits = c(0, maxY), breaks = seq(0, maxY, .02)) + 
                   theme_bw() + xlab('# of Predictors') + ylab('Misclass.') + facet_wrap(~group, switch = 'y')

}
grid.arrange(my.results$plots$NoNorm, my.results$plots$Center, my.results$plots$Max, nrow = 3)
```

![](tum_files/figure-markdown_github/unnamed-chunk-1-1.png)

-   Rank de p-values
-   Dados desbalanceados (Alexandra)
